
# Slot: catalyst qualifier


this connects the derivation edge to the molecular entity that catalyzes the reaction that causes the subject chemical to transform into the object chemical.

URI: [biolink:chemical_to_chemical_derivation_association_catalyst_qualifier](https://w3id.org/biolink/vocab/chemical_to_chemical_derivation_association_catalyst_qualifier)


## Domain and Range

[ChemicalToChemicalDerivationAssociation](ChemicalToChemicalDerivationAssociation.md) &#8594;  <sub>0..\*</sub> [MacromolecularMachineMixin](MacromolecularMachineMixin.md)

## Parents

 *  is_a: [catalyst qualifier](catalyst_qualifier.md)

## Children


## Used by

 * [ChemicalToChemicalDerivationAssociation](ChemicalToChemicalDerivationAssociation.md)
